@@ -1,3 +1,12 @@
+if (!isGeneric("bayesglm")) {
+    setGeneric("bayesglm",
+               function(formula, ...)
+               standardGeneric("bayesglm"))
+}
+
+
+
+
 if (!isGeneric("coefplot")) {
     setGeneric("coefplot",
                function(object, ...)
@@ -11,6 +20,12 @@ if (!isGeneric("display")) {
                standardGeneric("display"))
 }
 
+if (!isGeneric("model.matrix.bayes")) {
+    setGeneric("model.matrix.bayes",
+               function(object, ...)
+               standardGeneric("model.matrix.bayes"))
+}
+
 
 if (!isGeneric("sim")) {
     setGeneric("sim",
@@ -32,12 +47,6 @@ if (!isGeneric("se.coef")) {
 }
 
 
-if (!isGeneric("terms")) {
-    setGeneric("terms",
-               function(x,...)
-               standardGeneric("terms"))
-}
-
 if (!isGeneric("mcsamp")) {
     setGeneric("mcsamp",
                function(object, ...)
@@ -45,4 +54,11 @@ if (!isGeneric("mcsamp")) {
 }
 
 
+if (!isGeneric("terms.bayes")) {
+    setGeneric("terms.bayes",
+               function(x, ...)
+               standardGeneric("terms.bayes"))
+}
+
+
    
